#include <FL/Fl.H>
#include <FL/Fl_Window.H>
#include <FL/fl_draw.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Button.H>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

static Fl_Window *main_win;
static Fl_Button *textobj;
static int total_fonts = 0;
static char win_title[128];
static char label[40];

void next_font (void*) {
	static int fnt_idx = -1;
	int attribs;
	fnt_idx ++; // for each font in turn
	if (fnt_idx >= total_fonts) fnt_idx = 0;

	// Change the face associated with a given "fltk" font... This changes the
	// font that is actually drawn when you ask for FL_HELVETICA
	Fl::set_font(FL_HELVETICA, (Fl_Font)fnt_idx); // Not working under win32?
//	textobj->labelfont((Fl_Font)fnt_idx); // but doing this does work - for fonts up to index 255

	// update window title to show font description
	sprintf(win_title, "%d: %s", fnt_idx, Fl::get_font_name((Fl_Font)fnt_idx, &attribs));
	main_win->label(win_title);

	// redraw the updated widget
	textobj->redraw();
	main_win->redraw();

	// and repeat ad infinitum...
	Fl::repeat_timeout(1.0, next_font);
}

int main(int argc, char **argv)
{
	Fl::args(argc, argv);
	Fl::get_system_colors();
	// create the outer window
	main_win = new Fl_Window(550,190);
	// create some generic text to put in the font display window
	strcpy(label, "Hello, world! Font Face Test String?");

	// create the font display widget
	textobj = new Fl_Button(10, 10, 530, 170, label);
	textobj->box(FL_BORDER_BOX);
	textobj->clear_visible_focus();
	main_win->end();

	// load ALL the fonts on the system
	total_fonts = Fl::set_fonts("*");

	// prepare the font widget and update the displayed font periodically
	next_font(NULL);

	// show the font widget
	main_win->show(argc,argv);
	return Fl::run();
}
/* End of File */
